==> bunny_sdk-0.0.15.tar.gz: bunny_sdk-0.0.15/bunny_sdk/bunny_api_client/pullzone/load_free_certificate/load_free_certificate_request_builder.py <==
from __future__ import annotations
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.default_query_parameters import QueryParameters
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union
from warnings import warn

class LoadFreeCertificateRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /pullzone/loadFreeCertificate
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, Dict[str, Any]]) -> None:
        """
        Instantiates a new LoadFreeCertificateRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/pullzone/loadFreeCertificate?hostname={hostname}", path_parameters)
    
    async def get(self,request_configuration: Optional[RequestConfiguration[LoadFreeCertificateRequestBuilderGetQueryParameters]] = None) -> bytes:
        """
        [LoadFreeCertificate API Docs](https://docs.bunny.net/reference/pullzonepublic_loadfreecertificate)
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: bytes
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        return await self.request_adapter.send_primitive_async(request_info, "bytes", None)
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration[LoadFreeCertificateRequestBuilderGetQueryParameters]] = None) -> RequestInformation:
        """
        [LoadFreeCertificate API Docs](https://docs.bunny.net/reference/pullzonepublic_loadfreecertificate)
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        return request_info
    
    def with_url(self,raw_url: str) -> LoadFreeCertificateRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: LoadFreeCertificateRequestBuilder
        """
        if raw_url is None:
            raise TypeError("raw_url cannot be null.")
        return LoadFreeCertificateRequestBuilder(self.request_adapter, raw_url)
    
    @dataclass
    class LoadFreeCertificateRequestBuilderGetQueryParameters():
        """
        [LoadFreeCertificate API Docs](https://docs.bunny.net/reference/pullzonepublic_loadfreecertificate)
        """
        # The hostname that the certificate will be loaded for
        hostname: Optional[str] = None

    
    @dataclass
    class LoadFreeCertificateRequestBuilderGetRequestConfiguration(RequestConfiguration[LoadFreeCertificateRequestBuilderGetQueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)

==> bunny_sdk-0.0.16.tar.gz: bunny_sdk-0.0.16/bunny_sdk/bunny_api_client/pullzone/load_free_certificate/load_free_certificate_request_builder.py <==
from __future__ import annotations
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.default_query_parameters import QueryParameters
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union
from warnings import warn

class LoadFreeCertificateRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /pullzone/loadFreeCertificate
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, Dict[str, Any]]) -> None:
        """
        Instantiates a new LoadFreeCertificateRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/pullzone/loadFreeCertificate?hostname={hostname}", path_parameters)
    
    async def get(self,request_configuration: Optional[RequestConfiguration[LoadFreeCertificateRequestBuilderGetQueryParameters]] = None) -> Optional[bytes]:
        """
        [LoadFreeCertificate API Docs](https://docs.bunny.net/reference/pullzonepublic_loadfreecertificate)
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: bytes
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        return await self.request_adapter.send_primitive_async(request_info, "bytes", None)
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration[LoadFreeCertificateRequestBuilderGetQueryParameters]] = None) -> RequestInformation:
        """
        [LoadFreeCertificate API Docs](https://docs.bunny.net/reference/pullzonepublic_loadfreecertificate)
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        return request_info
    
    def with_url(self,raw_url: str) -> LoadFreeCertificateRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: LoadFreeCertificateRequestBuilder
        """
        if raw_url is None:
            raise TypeError("raw_url cannot be null.")
        return LoadFreeCertificateRequestBuilder(self.request_adapter, raw_url)
    
    @dataclass
    class LoadFreeCertificateRequestBuilderGetQueryParameters():
        """
        [LoadFreeCertificate API Docs](https://docs.bunny.net/reference/pullzonepublic_loadfreecertificate)
        """
        # The hostname that the certificate will be loaded for
        hostname: Optional[str] = None

    
    @dataclass
    class LoadFreeCertificateRequestBuilderGetRequestConfiguration(RequestConfiguration[LoadFreeCertificateRequestBuilderGetQueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
